@@ -2,6 +2,7 @@ use crate::uncles_verifier::{UncleProvider, UnclesVerifier};
 use ckb_async_runtime::Handle;
 use ckb_chain_spec::consensus::{Consensus, ConsensusProvider};
 use ckb_dao::DaoCalculator;
+use ckb_dao_utils::DaoError;
 use ckb_error::Error;
 use ckb_logger::error_target;
 use ckb_metrics::{metrics, Timer};
@@ -43,7 +44,10 @@ impl<'a, CS: ChainStore<'a>> VerifyContext<'a, CS> {
         VerifyContext { store, consensus }
     }
 
-    fn finalize_block_reward(&self, parent: &HeaderView) -> Result<(Script, BlockReward), Error> {
+    fn finalize_block_reward(
+        &self,
+        parent: &HeaderView,
+    ) -> Result<(Script, BlockReward), DaoError> {
         RewardCalculator::new(self.consensus, self.store).block_reward_to_finalize(parent)
     }
 }
@@ -56,6 +60,9 @@ impl<'a, CS: ChainStore<'a>> HeaderProvider for VerifyContext<'a, CS> {
 
 impl<'a, CS: ChainStore<'a>> HeaderChecker for VerifyContext<'a, CS> {
     fn check_valid(&self, block_hash: &Byte32) -> Result<(), OutPointError> {
+        if !self.store.is_main_chain(block_hash) {
+            return Err(OutPointError::InvalidHeader(block_hash.clone()));
+        }
         match self.store.get_block_header(block_hash) {
             Some(header) => {
                 let tip_header = self.store.get_tip_header().expect("tip should exist");
@@ -182,9 +189,7 @@ impl<'a, CS: ChainStore<'a>> TwoPhaseCommitVerifier<'a, CS> {
             .map(TransactionView::proposal_short_id)
             .collect();
 
-        let difference: Vec<_> = committed_ids.difference(&proposal_txs_ids).collect();
-
-        if !difference.is_empty() {
+        if committed_ids.difference(&proposal_txs_ids).next().is_some() {
             error_target!(
                 crate::LOG_TARGET,
                 "BlockView {} {}",
